@@ -81,11 +81,9 @@ class CommonDump():
     def statistics_status(self, is_end: bool = False):
         if is_end:
             g = self.global_start_time
-            g = time.strftime(g)
             cost = time.time() - g
             cost = math.ceil(cost*1e3)
-            print(f'[+] completed,cost {cost}ms',
-                  f'start at {g}', f'with result:{self.result}')
+            print(f'[+] completed,cost {cost}ms', f'with result:{self.result}')
             return
         self.global_start_time = time.time()
 
@@ -141,10 +139,11 @@ class CommonDump():
             os.makedirs(current_directory)
         children_package = arch.toc
         if isinstance(children_package, dict):
-            children_package = filter(
-                lambda x: not x.startswith('_'), list(children_package))
+            children_package = list(filter(
+                lambda x: not x.startswith('_'), list(children_package)))
         else:
             children_package = children_package.data
+        children_package = list(children_package)
         self.total_handled_count += len(children_package)
         for package in children_package:
             p = PackageDescription(package, arch, current_directory)
